import { AnalyzedElementType, FindElementSelector, ImportedElement, ImportElement, ShapeModificationCallback, ShapeTargetType, SlideModificationCallback, SourceIdentifier, Target } from '../types/types';
import { IPresentationProps } from '../interfaces/ipresentation-props';
import { PresTemplate } from '../interfaces/pres-template';
import { RootPresTemplate } from '../interfaces/root-pres-template';
import { HelperElement, XmlDocument } from '../types/xml-types';
import IArchive from '../interfaces/iarchive';
import { IMaster } from '../interfaces/imaster';
import HasShapes from './has-shapes';
export declare class Master extends HasShapes implements IMaster {
    targetType: ShapeTargetType;
    constructor(params: {
        presentation: IPresentationProps;
        template: PresTemplate;
        sourceIdentifier: SourceIdentifier;
    });
    /**
     * ToDo: Implement creationIds as well for slideMasters
     *
     * Try to convert a given slide's creationId to corresponding slide number.
     * Used if automizer is run with useCreationIds: true
     * @internal
     * @param PresTemplate
     * @slideNumber SourceSlideIdentifier
     * @returns number
     */
    getSlideNumber(template: PresTemplate, slideIdentifier: SourceIdentifier): number;
    /**
     * Appends slide
     * @internal
     * @param targetTemplate
     * @returns append
     */
    append(targetTemplate: RootPresTemplate): Promise<void>;
    copyRelatedLayouts(): Promise<Target[]>;
    copyThemeFiles(): Promise<void>;
    /**
     * Modifies slide
     * @internal
     * @param callback
     */
    modify(callback: SlideModificationCallback): void;
    /**
     * Adds slide to presentation
     * @internal
     * @returns slide to presentation
     */
    addSlideMasterToPresentation(): Promise<void>;
    /**
     * ToDo: This equals the corresponding method in slide.ts
     *
     * Select and modify a single element on an added slide.
     * @param {string} selector - Element's name on the slide.
     * Should be a unique string defined on the "Selection"-pane within ppt.
     * @param {ShapeModificationCallback | ShapeModificationCallback[]} callback - One or more callback functions to apply.
     * Depending on the shape type (e.g. chart or table), different arguments will be passed to the callback.
     */
    modifyElement(selector: FindElementSelector, callback: ShapeModificationCallback | ShapeModificationCallback[]): this;
    /**
     * ToDo: This equals the corresponding method in slide.ts
     *
     * Select, insert and (optionally) modify a single element to a slide.
     * @param {string} presName - Filename or alias name of the template presentation.
     * Must have been importet with Automizer.load().
     * @param {number} slideNumber - Slide number within the specified template to search for the required element.
     * @param {ShapeModificationCallback | ShapeModificationCallback[]} callback - One or more callback functions to apply.
     * Depending on the shape type (e.g. chart or table), different arguments will be passed to the callback.
     */
    addElement(presName: string, slideNumber: number, selector: FindElementSelector, callback?: ShapeModificationCallback | ShapeModificationCallback[]): this;
    /**
     * ToDo: This equals the corresponding method in slide.ts
     *
     * Remove a single element from slide.
     * @param {string} selector - Element's name on the slide.
     */
    removeElement(selector: FindElementSelector): this;
    /**
     * ToDo: This equals the corresponding method in slide.ts
     *
     * Adds element to modifications list
     * @internal
     * @param presName
     * @param slideNumber
     * @param selector
     * @param mode
     * @param [callback]
     * @returns element to modifications list
     */
    private addElementToModificationsList;
    /**
     * ToDo: This equals the corresponding method in slide.ts
     *
     * Imported selected elements
     * @internal
     * @returns selected elements
     */
    importedSelectedElements(): Promise<void>;
    /**
     * ToDo: This *ALMOST* equals the corresponding method in slide.ts
     *
     * Gets element info
     * @internal
     * @param importElement
     * @returns element info
     */
    getElementInfo(importElement: ImportElement): Promise<ImportedElement>;
    /**
     * ToDo: This equals the corresponding method in slide.ts
     *
     * @param selector
     * @param sourceArchive
     * @param sourcePath
     * @param useCreationIds
     */
    findElementOnSlide(selector: FindElementSelector, sourceArchive: IArchive, sourcePath: string, useCreationIds: boolean): Promise<{
        sourceElement: XmlDocument;
        selector: string;
    }>;
    /**
     * ToDo: This equals the corresponding method in slide.ts
     *
     * Analyzes element
     * @internal
     * @param sourceElement
     * @param sourceArchive
     * @param slideNumber
     * @returns element
     */
    analyzeElement(sourceElement: XmlDocument, sourceArchive: IArchive, slideNumber: number): Promise<AnalyzedElementType>;
    /**
     * ToDo: This equals the corresponding method in slide.ts
     *
     * Applys modifications
     * @internal
     * @returns modifications
     */
    applyModifications(): Promise<void>;
    /**
     * ToDo: This *almost* equals the corresponding method in slide.ts
     *
     * Removes all unsupported tags from slide xml.
     * E.g. added relations & tags by Thinkcell cannot
     * be processed by pptx-automizer at the moment.
     * @internal
     */
    cleanSlide(targetPath: string): Promise<void>;
    /**
     * Copys slide files
     * @internal
     */
    copySlideFiles(): Promise<void>;
    /**
     * Appends to slide rel
     * @internal
     * @param rootArchive
     * @param relId
     * @param slideCount
     * @returns to slide rel
     */
    appendToSlideRel(rootArchive: IArchive, relId: string, slideCount: number): Promise<HelperElement>;
    /**
     * Appends a new slide to slide list in presentation.xml.
     * If rootArchive has no slides, a new node will be created.
     * "id"-attribute of 'p:sldId'-element must be greater than 255.
     * @internal
     * @param rootArchive
     * @param relId
     * @returns to slide list
     */
    appendToSlideList(rootArchive: IArchive, relId: string): Promise<HelperElement>;
    /**
     * Appends slide to content type
     * @internal
     * @param rootArchive
     * @param slideCount
     * @returns slide to content type
     */
    appendSlideMasterToContentType(rootArchive: IArchive, slideCount: number): Promise<HelperElement>;
    appendSlideLayoutToContentType(rootArchive: IArchive, slideLayoutCount: number): Promise<HelperElement>;
    appendThemeToContentType(rootArchive: IArchive, themeCount: string | number): Promise<HelperElement>;
    /**
     * ToDo: This equals the corresponding method in slide.ts
     *
     * Appends notes to content type
     * @internal
     * @param rootArchive
     * @param slideCount
     * @returns notes to content type
     */
    appendNotesToContentType(rootArchive: IArchive, slideCount: number): Promise<HelperElement>;
    /**
     * ToDo: This equals the corresponding method in slide.ts
     *
     * Copys related content
     * @internal
     * @returns related content
     */
    copyRelatedContent(): Promise<void>;
}
